export function formatDateForInput(date, type, format) {
    if (type === void 0) { type = 'date'; }
    if (format === void 0) { format = 'YYYY-MM-DD'; }
    if (!date)
        return '';
    try {
        var dt = new Date(date);
        if (isNaN(dt.getTime()))
            return '';
        var year = dt.getFullYear();
        var month = "".concat(dt.getMonth() + 1).padStart(2, '0');
        var day = "".concat(dt.getDate()).padStart(2, '0');
        if (type === 'date') {
            switch (format) {
                case 'YYYY-MM-DD':
                    return "".concat(year, "-").concat(month, "-").concat(day);
                case 'DD-MM-YYYY':
                    return "".concat(day, "-").concat(month, "-").concat(year);
                default:
                    return "".concat(year, "-").concat(month, "-").concat(day);
            }
        }
        var hours = "".concat(dt.getHours()).padStart(2, '0');
        var minutes = "".concat(dt.getMinutes()).padStart(2, '0');
        switch (format) {
            case 'YYYY-MM-DD':
                return "".concat(year, "-").concat(month, "-").concat(day, "T").concat(hours, ":").concat(minutes);
            case 'DD-MM-YYYY':
                return "".concat(day, "-").concat(month, "-").concat(year, " ").concat(hours, ":").concat(minutes);
            default:
                return "".concat(year, "-").concat(month, "-").concat(day, "T").concat(hours, ":").concat(minutes);
        }
    }
    catch (_a) {
        return '';
    }
}
export function convertValueTimeParameter(value) {
    if (!value)
        return '';
    var now = new Date();
    if (value === '$$year')
        return now.getFullYear().toString();
    if (value === '$$month')
        return (now.getMonth() + 1).toString();
    if (value === '$$day')
        return now.getDate().toString();
    var regex = /^\$\$(today|now)([+-])?(\d+)?(days|months|years|weeks|hours|minutes|seconds|milliseconds)?$/;
    var match = value.match(regex);
    if (!match)
        return value;
    var base = match[1], operator = match[2], amountStr = match[3], unit = match[4];
    var offset = amountStr ? parseInt(amountStr) * (operator === '-' ? -1 : 1) : 0;
    var dt = new Date();
    if (base === 'today') {
        dt.setHours(0, 0, 0, 0);
    }
    if (unit) {
        switch (unit) {
            case 'days':
                dt.setDate(dt.getDate() + offset);
                break;
            case 'weeks':
                dt.setDate(dt.getDate() + offset * 7);
                break;
            case 'months':
                dt.setMonth(dt.getMonth() + offset);
                break;
            case 'years':
                dt.setFullYear(dt.getFullYear() + offset);
                break;
            case 'hours':
                dt.setHours(dt.getHours() + offset);
                break;
            case 'minutes':
                dt.setMinutes(dt.getMinutes() + offset);
                break;
            case 'seconds':
                dt.setSeconds(dt.getSeconds() + offset);
                break;
            case 'milliseconds':
                dt.setMilliseconds(dt.getMilliseconds() + offset);
                break;
        }
    }
    return dt.toISOString();
}
